@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Hayo Baan's Dist::Zilla configuration
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 #pod =head1 DESCRIPTION
 #pod
@@ -39,6 +39,7 @@ our $VERSION = '0.011'; # VERSION
 #pod * L<Manifest|Dist::Zilla::Plugin::Manifest>
 #pod * L<CopyFilesFromBuild|Dist::Zilla::Plugin::CopyFilesFromBuild>
 #pod * L<Run::AfterBuild|Dist::Zilla::Plugin::Run::AfterBuild>
+#pod * L<GitHubREADME::Badge|Dist::Zilla::Plugin::GitHubREADME::Badge>
 #pod * L<CheckChangesHasContent|Dist::Zilla::Plugin::CheckChangesHasContent>
 #pod * L<Git::CheckFor::CorrectBranch|Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch>
 #pod * L<Git::Check|Dist::Zilla::Plugin::Git::Check>
@@ -148,6 +149,7 @@ require Dist::Zilla::Plugin::MetaProvides::Package;
 require Dist::Zilla::Plugin::MetaProvides::Class;
 require Dist::Zilla::Plugin::CopyFilesFromBuild;
 require Dist::Zilla::Plugin::Run;
+require Dist::Zilla::Plugin::GitHubREADME::Badge;
 require Dist::Zilla::Plugin::CheckChangesHasContent;
 require Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch;
 require Dist::Zilla::Plugin::Git::Check;
@@ -591,7 +593,9 @@ has copy_build_files => (
     is  => 'ro',
     isa => 'ArrayRef[Str]',
     lazy => 1,
-    default => sub { [ qw(Build.PL Makefile.PL README README.mkdn) ] },
+    default => sub { [ ($_[0]->use_modulebuild ? qw(Build.PL) : ()),
+                       ($_[0]->use_makemaker ? qw(Makefile.PL) : ()),
+                       qw(README README.mkdn) ] },
 );
 
 # Files to exclude from gatherer
@@ -766,6 +770,11 @@ sub configure {
             [ 'Run::AfterBuild' => { run => $self->run_after_build } ],
         ) : (),
 
+        $self->is_github_hosted && $self->is_cpan ? (
+            # Add status badges to README.mkdn
+            [ 'GitHubREADME::Badge' => { ':version' => '0.16', badges => [ qw(travis cpants) ] } ],
+        ) : (),
+
         #### Before Release Tests ####
         !$self->local_release_only ? (
             # Check if Changes file has content
@@ -910,7 +919,7 @@ Dist::Zilla::PluginBundle::Author::HAYOBAAN - Hayo Baan's Dist::Zilla configurat
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 DESCRIPTION
 
@@ -1026,6 +1035,10 @@ L<Run::AfterBuild|Dist::Zilla::Plugin::Run::AfterBuild>
 
 =item *
 
+L<GitHubREADME::Badge|Dist::Zilla::Plugin::GitHubREADME::Badge>
+
+=item *
+
 L<CheckChangesHasContent|Dist::Zilla::Plugin::CheckChangesHasContent>
 
 =item *
@@ -1555,7 +1568,7 @@ Mike Doherty L<DOHERTY|Dist::Zilla::PluginBundle::Author::DOHERTY>
 
 =head1 AUTHOR
 
-Hayo Baan <hayobaan@cpan.org>
+Hayo Baan <info@hayobaan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
