@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: HAYOBAAN's Pod::Weaver configuration
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 #pod =head1 DESCRIPTION
 #pod
@@ -193,7 +193,7 @@ Pod::Weaver::PluginBundle::Author::HAYOBAAN - HAYOBAAN's Pod::Weaver configurati
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 DESCRIPTION
 
@@ -364,7 +364,7 @@ L<Dist::Zilla::Plugin::PodWeaver>
 
 =head1 AUTHOR
 
-Hayo Baan <hayobaan@cpan.org>
+Hayo Baan <info@hayobaan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
