@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Improved version of Pod::Weaver::Section::Bugs, adds proper links to the BUGS pod section
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -101,7 +101,7 @@ Pod::Weaver::Section::Author::HAYOBAAN::Bugs - Improved version of Pod::Weaver::
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 OVERVIEW
 
@@ -147,7 +147,7 @@ The original L<Section::Bugs|Pod::Weaver::Section::Bugs> plugin.
 
 =head1 AUTHOR
 
-Hayo Baan <hayobaan@cpan.org>
+Hayo Baan <info@hayobaan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
